AddressValidation

Struct AddressValidation 

pub struct AddressValidation { /* private fields */ }
Implements a client for the Address Validation API.

Example

async fn sample(
) -> anyhow::Result<()> {
    let client = AddressValidation::builder().build().await?;
    let response = client.validate_address()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}

Service Description

The service for validating addresses.

Configuration

To configure AddressValidation use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

AddressValidation holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap AddressValidation in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl AddressValidation

pub fn builder() -> ClientBuilder

Returns a builder for AddressValidation.

let client = AddressValidation::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: AddressValidation + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn validate_address(&self) -> ValidateAddress

Validates an address.

Example
use google_maps_addressvalidation_v1::Result;
async fn sample(
   client: &AddressValidation
) -> Result<()> {
    let response = client.validate_address()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn provide_validation_feedback(&self) -> ProvideValidationFeedback

Feedback about the outcome of the sequence of validation attempts. This should be the last call made after a sequence of validation calls for the same address, and should be called once the transaction is concluded. This should only be sent once for the sequence of ValidateAddress requests needed to validate an address fully.

Example
use google_maps_addressvalidation_v1::Result;
async fn sample(
   client: &AddressValidation
) -> Result<()> {
    let response = client.provide_validation_feedback()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}